'use strict';

var fastembed = require('fastembed');

// For CommonJS
// const { EmbeddingModel, FlagEmbedding } = require("fastembed)
class FastEmbedding {
    constructor(type) {
        this.type = type;
        this.cacheDir = './cache_embedding';
        this.embedDocuments = async (documents, batchSize = 10) => {
            const embeddingModel = await fastembed.FlagEmbedding.init({
                model: this.model,
                cacheDir: this.cacheDir,
            });
            const batchs = embeddingModel.embed(documents, batchSize); //Optional batch size. Defaults to 256
            const embeddingsArray = [];
            for await (const batch of batchs) {
                // batch is list of Float32 embeddings(number[][])
                embeddingsArray.push(batch.map(b => Array.from(b)));
            }
            // console.log(await embedDocuments(['hello', 'world'], 10))
            return embeddingsArray[0];
        };
        this.embedQuery = async (query) => {
            const embeddingModel = await fastembed.FlagEmbedding.init({
                model: this.model,
                cacheDir: this.cacheDir,
            });
            const embeddingsArray = await embeddingModel.queryEmbed(query);
            // console.log(await embedQuery('hola'))
            return Array.from(embeddingsArray);
        };
        this.model = fastembed.EmbeddingModel[this.type];
    }
    getInstance() {
        return this.model;
    }
    async getDimension() {
        return (await this.embedQuery('foo')).length;
    }
}

exports.FastEmbedding = FastEmbedding;
